# Contributors

Thank you to all the contributors who have helped make dao-ai possible!

## Core Contributors

- **Nate Fleming** ([@natefleming-db](https://github.com/natefleming-db)) - Project creator and lead maintainer

## Contributors

- **Peter Park** ([@park-peter](https://github.com/park-peter))
- **Dipankar Kush** ([@dipankarkush-db](https://github.com/dipankarkush-db))

---

We appreciate every contribution, whether it's code, documentation, bug reports, or feature suggestions. If you'd like to contribute, please see our [Contributing Guide](CONTRIBUTING.md).
